MediaFile class

Constructors

MediaFile.file({required String id, required File file, required MediaType type})
MediaFile.medium(Medium medium)

Properties

file → File?
no setter
hashCode → int
The hash code for this object.
no setterinherited
id → String
no setter
isImage → bool
no setter
isVideo → bool
no setter
lastModified → DateTime?
no setter
medium → Medium?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
thumbnail ↔ Uint8List?
getter/setter pair
type → MediaType
no setter

Methods

getData() → Future<Uint8List>
getFile() → Future<File>
getThumbnail({bool highQuality = true}) → Future<Uint8List>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited